@@ -20,8 +20,11 @@ def _get_kwargs(
     after: Union[Unset, None, datetime.datetime] = UNSET,
     username: Union[Unset, None, str] = UNSET,
     operation: Union[Unset, None, str] = UNSET,
+    operations: Union[Unset, None, str] = UNSET,
+    exclude_operations: Union[Unset, None, str] = UNSET,
     resource: Union[Unset, None, str] = UNSET,
     action_kind: Union[Unset, None, ListAuditLogsActionKind] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -46,6 +49,10 @@ def _get_kwargs(
 
     params["operation"] = operation
 
+    params["operations"] = operations
+
+    params["exclude_operations"] = exclude_operations
+
     params["resource"] = resource
 
     json_action_kind: Union[Unset, None, str] = UNSET
@@ -54,6 +61,8 @@ def _get_kwargs(
 
     params["action_kind"] = json_action_kind
 
+    params["all_workspaces"] = all_workspaces
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -104,8 +113,11 @@ def sync_detailed(
     after: Union[Unset, None, datetime.datetime] = UNSET,
     username: Union[Unset, None, str] = UNSET,
     operation: Union[Unset, None, str] = UNSET,
+    operations: Union[Unset, None, str] = UNSET,
+    exclude_operations: Union[Unset, None, str] = UNSET,
     resource: Union[Unset, None, str] = UNSET,
     action_kind: Union[Unset, None, ListAuditLogsActionKind] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListAuditLogsResponse200Item"]]:
     """list audit logs (requires admin privilege)
 
@@ -117,8 +129,11 @@ def sync_detailed(
         after (Union[Unset, None, datetime.datetime]):
         username (Union[Unset, None, str]):
         operation (Union[Unset, None, str]):
+        operations (Union[Unset, None, str]):
+        exclude_operations (Union[Unset, None, str]):
         resource (Union[Unset, None, str]):
         action_kind (Union[Unset, None, ListAuditLogsActionKind]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -136,8 +151,11 @@ def sync_detailed(
         after=after,
         username=username,
         operation=operation,
+        operations=operations,
+        exclude_operations=exclude_operations,
         resource=resource,
         action_kind=action_kind,
+        all_workspaces=all_workspaces,
     )
 
     response = client.get_httpx_client().request(
@@ -157,8 +175,11 @@ def sync(
     after: Union[Unset, None, datetime.datetime] = UNSET,
     username: Union[Unset, None, str] = UNSET,
     operation: Union[Unset, None, str] = UNSET,
+    operations: Union[Unset, None, str] = UNSET,
+    exclude_operations: Union[Unset, None, str] = UNSET,
     resource: Union[Unset, None, str] = UNSET,
     action_kind: Union[Unset, None, ListAuditLogsActionKind] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListAuditLogsResponse200Item"]]:
     """list audit logs (requires admin privilege)
 
@@ -170,8 +191,11 @@ def sync(
         after (Union[Unset, None, datetime.datetime]):
         username (Union[Unset, None, str]):
         operation (Union[Unset, None, str]):
+        operations (Union[Unset, None, str]):
+        exclude_operations (Union[Unset, None, str]):
         resource (Union[Unset, None, str]):
         action_kind (Union[Unset, None, ListAuditLogsActionKind]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -190,8 +214,11 @@ def sync(
         after=after,
         username=username,
         operation=operation,
+        operations=operations,
+        exclude_operations=exclude_operations,
         resource=resource,
         action_kind=action_kind,
+        all_workspaces=all_workspaces,
     ).parsed
 
 
@@ -205,8 +232,11 @@ async def asyncio_detailed(
     after: Union[Unset, None, datetime.datetime] = UNSET,
     username: Union[Unset, None, str] = UNSET,
     operation: Union[Unset, None, str] = UNSET,
+    operations: Union[Unset, None, str] = UNSET,
+    exclude_operations: Union[Unset, None, str] = UNSET,
     resource: Union[Unset, None, str] = UNSET,
     action_kind: Union[Unset, None, ListAuditLogsActionKind] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Response[List["ListAuditLogsResponse200Item"]]:
     """list audit logs (requires admin privilege)
 
@@ -218,8 +248,11 @@ async def asyncio_detailed(
         after (Union[Unset, None, datetime.datetime]):
         username (Union[Unset, None, str]):
         operation (Union[Unset, None, str]):
+        operations (Union[Unset, None, str]):
+        exclude_operations (Union[Unset, None, str]):
         resource (Union[Unset, None, str]):
         action_kind (Union[Unset, None, ListAuditLogsActionKind]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -237,8 +270,11 @@ async def asyncio_detailed(
         after=after,
         username=username,
         operation=operation,
+        operations=operations,
+        exclude_operations=exclude_operations,
         resource=resource,
         action_kind=action_kind,
+        all_workspaces=all_workspaces,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -256,8 +292,11 @@ async def asyncio(
     after: Union[Unset, None, datetime.datetime] = UNSET,
     username: Union[Unset, None, str] = UNSET,
     operation: Union[Unset, None, str] = UNSET,
+    operations: Union[Unset, None, str] = UNSET,
+    exclude_operations: Union[Unset, None, str] = UNSET,
     resource: Union[Unset, None, str] = UNSET,
     action_kind: Union[Unset, None, ListAuditLogsActionKind] = UNSET,
+    all_workspaces: Union[Unset, None, bool] = UNSET,
 ) -> Optional[List["ListAuditLogsResponse200Item"]]:
     """list audit logs (requires admin privilege)
 
@@ -269,8 +308,11 @@ async def asyncio(
         after (Union[Unset, None, datetime.datetime]):
         username (Union[Unset, None, str]):
         operation (Union[Unset, None, str]):
+        operations (Union[Unset, None, str]):
+        exclude_operations (Union[Unset, None, str]):
         resource (Union[Unset, None, str]):
         action_kind (Union[Unset, None, ListAuditLogsActionKind]):
+        all_workspaces (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -290,7 +332,10 @@ async def asyncio(
             after=after,
             username=username,
             operation=operation,
+            operations=operations,
+            exclude_operations=exclude_operations,
             resource=resource,
             action_kind=action_kind,
+            all_workspaces=all_workspaces,
         )
     ).parsed
