@@ -5,21 +5,29 @@ import httpx
 
 from ... import errors
 from ...client import AuthenticatedClient, Client
-from ...types import Response
+from ...types import UNSET, Response, Unset
 
 
 def _get_kwargs(
     workspace: str,
     path: str,
+    *,
+    keep_captures: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
+    params: Dict[str, Any] = {}
+    params["keep_captures"] = keep_captures
+
+    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
+
     return {
         "method": "delete",
         "url": "/w/{workspace}/flows/delete/{path}".format(
             workspace=workspace,
             path=path,
         ),
+        "params": params,
     }
 
 
@@ -44,12 +52,14 @@ def sync_detailed(
     path: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    keep_captures: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """delete flow by path
 
     Args:
         workspace (str):
         path (str):
+        keep_captures (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -62,6 +72,7 @@ def sync_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
+        keep_captures=keep_captures,
     )
 
     response = client.get_httpx_client().request(
@@ -76,12 +87,14 @@ async def asyncio_detailed(
     path: str,
     *,
     client: Union[AuthenticatedClient, Client],
+    keep_captures: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """delete flow by path
 
     Args:
         workspace (str):
         path (str):
+        keep_captures (Union[Unset, None, bool]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -94,6 +107,7 @@ async def asyncio_detailed(
     kwargs = _get_kwargs(
         workspace=workspace,
         path=path,
+        keep_captures=keep_captures,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
