@@ -7,6 +7,12 @@ from ..models.completed_job_flow_status_modules_item_type import CompletedJobFlo
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.completed_job_flow_status_modules_item_agent_actions_item_type_0 import (
+        CompletedJobFlowStatusModulesItemAgentActionsItemType0,
+    )
+    from ..models.completed_job_flow_status_modules_item_agent_actions_item_type_1 import (
+        CompletedJobFlowStatusModulesItemAgentActionsItemType1,
+    )
     from ..models.completed_job_flow_status_modules_item_approvers_item import (
         CompletedJobFlowStatusModulesItemApproversItem,
     )
@@ -37,6 +43,9 @@ class CompletedJobFlowStatusModulesItem:
         approvers (Union[Unset, List['CompletedJobFlowStatusModulesItemApproversItem']]):
         failed_retries (Union[Unset, List[str]]):
         skipped (Union[Unset, bool]):
+        agent_actions (Union[Unset, List[Union['CompletedJobFlowStatusModulesItemAgentActionsItemType0',
+            'CompletedJobFlowStatusModulesItemAgentActionsItemType1']]]):
+        agent_actions_success (Union[Unset, List[bool]]):
     """
 
     type: CompletedJobFlowStatusModulesItemType
@@ -52,9 +61,23 @@ class CompletedJobFlowStatusModulesItem:
     approvers: Union[Unset, List["CompletedJobFlowStatusModulesItemApproversItem"]] = UNSET
     failed_retries: Union[Unset, List[str]] = UNSET
     skipped: Union[Unset, bool] = UNSET
+    agent_actions: Union[
+        Unset,
+        List[
+            Union[
+                "CompletedJobFlowStatusModulesItemAgentActionsItemType0",
+                "CompletedJobFlowStatusModulesItemAgentActionsItemType1",
+            ]
+        ],
+    ] = UNSET
+    agent_actions_success: Union[Unset, List[bool]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.completed_job_flow_status_modules_item_agent_actions_item_type_0 import (
+            CompletedJobFlowStatusModulesItemAgentActionsItemType0,
+        )
+
         type = self.type.value
 
         id = self.id
@@ -94,6 +117,23 @@ class CompletedJobFlowStatusModulesItem:
             failed_retries = self.failed_retries
 
         skipped = self.skipped
+        agent_actions: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.agent_actions, Unset):
+            agent_actions = []
+            for agent_actions_item_data in self.agent_actions:
+                agent_actions_item: Dict[str, Any]
+
+                if isinstance(agent_actions_item_data, CompletedJobFlowStatusModulesItemAgentActionsItemType0):
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                else:
+                    agent_actions_item = agent_actions_item_data.to_dict()
+
+                agent_actions.append(agent_actions_item)
+
+        agent_actions_success: Union[Unset, List[bool]] = UNSET
+        if not isinstance(self.agent_actions_success, Unset):
+            agent_actions_success = self.agent_actions_success
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -126,11 +166,21 @@ class CompletedJobFlowStatusModulesItem:
             field_dict["failed_retries"] = failed_retries
         if skipped is not UNSET:
             field_dict["skipped"] = skipped
+        if agent_actions is not UNSET:
+            field_dict["agent_actions"] = agent_actions
+        if agent_actions_success is not UNSET:
+            field_dict["agent_actions_success"] = agent_actions_success
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.completed_job_flow_status_modules_item_agent_actions_item_type_0 import (
+            CompletedJobFlowStatusModulesItemAgentActionsItemType0,
+        )
+        from ..models.completed_job_flow_status_modules_item_agent_actions_item_type_1 import (
+            CompletedJobFlowStatusModulesItemAgentActionsItemType1,
+        )
         from ..models.completed_job_flow_status_modules_item_approvers_item import (
             CompletedJobFlowStatusModulesItemApproversItem,
         )
@@ -187,6 +237,36 @@ class CompletedJobFlowStatusModulesItem:
 
         skipped = d.pop("skipped", UNSET)
 
+        agent_actions = []
+        _agent_actions = d.pop("agent_actions", UNSET)
+        for agent_actions_item_data in _agent_actions or []:
+
+            def _parse_agent_actions_item(
+                data: object,
+            ) -> Union[
+                "CompletedJobFlowStatusModulesItemAgentActionsItemType0",
+                "CompletedJobFlowStatusModulesItemAgentActionsItemType1",
+            ]:
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    agent_actions_item_type_0 = CompletedJobFlowStatusModulesItemAgentActionsItemType0.from_dict(data)
+
+                    return agent_actions_item_type_0
+                except:  # noqa: E722
+                    pass
+                if not isinstance(data, dict):
+                    raise TypeError()
+                agent_actions_item_type_1 = CompletedJobFlowStatusModulesItemAgentActionsItemType1.from_dict(data)
+
+                return agent_actions_item_type_1
+
+            agent_actions_item = _parse_agent_actions_item(agent_actions_item_data)
+
+            agent_actions.append(agent_actions_item)
+
+        agent_actions_success = cast(List[bool], d.pop("agent_actions_success", UNSET))
+
         completed_job_flow_status_modules_item = cls(
             type=type,
             id=id,
@@ -201,6 +281,8 @@ class CompletedJobFlowStatusModulesItem:
             approvers=approvers,
             failed_retries=failed_retries,
             skipped=skipped,
+            agent_actions=agent_actions,
+            agent_actions_success=agent_actions_success,
         )
 
         completed_job_flow_status_modules_item.additional_properties = d
