@@ -42,7 +42,8 @@ class CreateHttpTriggersJsonBodyItem:
         wrap_body (Union[Unset, bool]):
         raw_string (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, CreateHttpTriggersJsonBodyItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, CreateHttpTriggersJsonBodyItemErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, CreateHttpTriggersJsonBodyItemRetry]):
     """
 
