@@ -34,7 +34,8 @@ class CreateMqttTriggerJsonBody:
         client_version (Union[Unset, CreateMqttTriggerJsonBodyClientVersion]):
         enabled (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, CreateMqttTriggerJsonBodyErrorHandlerArgs]):
+        error_handler_args (Union[Unset, CreateMqttTriggerJsonBodyErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, CreateMqttTriggerJsonBodyRetry]):
     """
 
