@@ -27,7 +27,8 @@ class CreateSqsTriggerJsonBody:
         message_attributes (Union[Unset, List[str]]):
         enabled (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, CreateSqsTriggerJsonBodyErrorHandlerArgs]):
+        error_handler_args (Union[Unset, CreateSqsTriggerJsonBodyErrorHandlerArgs]): The arguments to pass to the script
+            or flow
         retry (Union[Unset, CreateSqsTriggerJsonBodyRetry]):
     """
 
