@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type8Type(str, Enum):
-    GRAPHQL = "graphql"
+    AIAGENT = "aiagent"
 
     def __str__(self) -> str:
         return str(self.value)
