@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.get_flow_by_path_response_200_value_failure_module_retry import (
         GetFlowByPathResponse200ValueFailureModuleRetry,
     )
+    from ..models.get_flow_by_path_response_200_value_failure_module_skip_if import (
+        GetFlowByPathResponse200ValueFailureModuleSkipIf,
+    )
     from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
         GetFlowByPathResponse200ValueFailureModuleSleepType0,
     )
     from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1 import (
         GetFlowByPathResponse200ValueFailureModuleSleepType1,
     )
+    from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_all_iters_if import (
+        GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf,
+    )
     from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_if import (
         GetFlowByPathResponse200ValueFailureModuleStopAfterIf,
     )
@@ -36,6 +42,8 @@ class GetFlowByPathResponse200ValueFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetFlowByPathResponse200ValueFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, GetFlowByPathResponse200ValueFailureModuleSkipIf]):
         sleep (Union['GetFlowByPathResponse200ValueFailureModuleSleepType0',
             'GetFlowByPathResponse200ValueFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class GetFlowByPathResponse200ValueFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "GetFlowByPathResponse200ValueFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "GetFlowByPathResponse200ValueFailureModuleSleepType0",
         "GetFlowByPathResponse200ValueFailureModuleSleepType1",
@@ -79,6 +89,14 @@ class GetFlowByPathResponse200ValueFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class GetFlowByPathResponse200ValueFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class GetFlowByPathResponse200ValueFailureModule:
         from ..models.get_flow_by_path_response_200_value_failure_module_retry import (
             GetFlowByPathResponse200ValueFailureModuleRetry,
         )
+        from ..models.get_flow_by_path_response_200_value_failure_module_skip_if import (
+            GetFlowByPathResponse200ValueFailureModuleSkipIf,
+        )
         from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_0 import (
             GetFlowByPathResponse200ValueFailureModuleSleepType0,
         )
         from ..models.get_flow_by_path_response_200_value_failure_module_sleep_type_1 import (
             GetFlowByPathResponse200ValueFailureModuleSleepType1,
         )
+        from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_all_iters_if import (
+            GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf,
+        )
         from ..models.get_flow_by_path_response_200_value_failure_module_stop_after_if import (
             GetFlowByPathResponse200ValueFailureModuleStopAfterIf,
         )
@@ -177,6 +205,22 @@ class GetFlowByPathResponse200ValueFailureModule:
         else:
             stop_after_if = GetFlowByPathResponse200ValueFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = GetFlowByPathResponse200ValueFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, GetFlowByPathResponse200ValueFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = GetFlowByPathResponse200ValueFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class GetFlowByPathResponse200ValueFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
