@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry import (
         GetHubFlowByIdResponse200FlowValueModulesItemRetry,
     )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_skip_if import (
+        GetHubFlowByIdResponse200FlowValueModulesItemSkipIf,
+    )
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
         GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
     )
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_1 import (
         GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
     )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_all_iters_if import (
+        GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf,
+    )
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_if import (
         GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf,
     )
@@ -36,6 +42,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf]):
+        skip_if (Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemSkipIf]):
         sleep (Union['GetHubFlowByIdResponse200FlowValueModulesItemSleepType0',
             'GetHubFlowByIdResponse200FlowValueModulesItemSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
     id: str
     value: Any
     stop_after_if: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "GetHubFlowByIdResponse200FlowValueModulesItemSkipIf"] = UNSET
     sleep: Union[
         "GetHubFlowByIdResponse200FlowValueModulesItemSleepType0",
         "GetHubFlowByIdResponse200FlowValueModulesItemSleepType1",
@@ -79,6 +89,14 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_retry import (
             GetHubFlowByIdResponse200FlowValueModulesItemRetry,
         )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_skip_if import (
+            GetHubFlowByIdResponse200FlowValueModulesItemSkipIf,
+        )
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_0 import (
             GetHubFlowByIdResponse200FlowValueModulesItemSleepType0,
         )
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_sleep_type_1 import (
             GetHubFlowByIdResponse200FlowValueModulesItemSleepType1,
         )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_all_iters_if import (
+            GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf,
+        )
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item_stop_after_if import (
             GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf,
         )
@@ -177,6 +205,22 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
         else:
             stop_after_if = GetHubFlowByIdResponse200FlowValueModulesItemStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = GetHubFlowByIdResponse200FlowValueModulesItemStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, GetHubFlowByIdResponse200FlowValueModulesItemSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = GetHubFlowByIdResponse200FlowValueModulesItemSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItem:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
