@@ -15,17 +15,20 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential:
         attempts (Union[Unset, int]):
         multiplier (Union[Unset, int]):
         seconds (Union[Unset, int]):
+        random_factor (Union[Unset, int]):
     """
 
     attempts: Union[Unset, int] = UNSET
     multiplier: Union[Unset, int] = UNSET
     seconds: Union[Unset, int] = UNSET
+    random_factor: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         attempts = self.attempts
         multiplier = self.multiplier
         seconds = self.seconds
+        random_factor = self.random_factor
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -36,6 +39,8 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential:
             field_dict["multiplier"] = multiplier
         if seconds is not UNSET:
             field_dict["seconds"] = seconds
+        if random_factor is not UNSET:
+            field_dict["random_factor"] = random_factor
 
         return field_dict
 
@@ -48,10 +53,13 @@ class GetHubFlowByIdResponse200FlowValueModulesItemRetryExponential:
 
         seconds = d.pop("seconds", UNSET)
 
+        random_factor = d.pop("random_factor", UNSET)
+
         get_hub_flow_by_id_response_200_flow_value_modules_item_retry_exponential = cls(
             attempts=attempts,
             multiplier=multiplier,
             seconds=seconds,
+            random_factor=random_factor,
         )
 
         get_hub_flow_by_id_response_200_flow_value_modules_item_retry_exponential.additional_properties = d
