@@ -36,7 +36,8 @@ class GetKafkaTriggerResponse200:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, GetKafkaTriggerResponse200ErrorHandlerArgs]):
+        error_handler_args (Union[Unset, GetKafkaTriggerResponse200ErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, GetKafkaTriggerResponse200Retry]):
     """
 
