@@ -33,17 +33,17 @@ class Schedule:
         is_flow (bool):
         extra_perms (ScheduleExtraPerms):
         email (str):
-        args (Union[Unset, ScheduleArgs]):
+        args (Union[Unset, ScheduleArgs]): The arguments to pass to the script or flow
         error (Union[Unset, str]):
         on_failure (Union[Unset, str]):
         on_failure_times (Union[Unset, float]):
         on_failure_exact (Union[Unset, bool]):
-        on_failure_extra_args (Union[Unset, ScheduleOnFailureExtraArgs]):
+        on_failure_extra_args (Union[Unset, ScheduleOnFailureExtraArgs]): The arguments to pass to the script or flow
         on_recovery (Union[Unset, str]):
         on_recovery_times (Union[Unset, float]):
-        on_recovery_extra_args (Union[Unset, ScheduleOnRecoveryExtraArgs]):
+        on_recovery_extra_args (Union[Unset, ScheduleOnRecoveryExtraArgs]): The arguments to pass to the script or flow
         on_success (Union[Unset, str]):
-        on_success_extra_args (Union[Unset, ScheduleOnSuccessExtraArgs]):
+        on_success_extra_args (Union[Unset, ScheduleOnSuccessExtraArgs]): The arguments to pass to the script or flow
         ws_error_handler_muted (Union[Unset, bool]):
         retry (Union[Unset, ScheduleRetry]):
         summary (Union[Unset, str]):
