@@ -38,7 +38,7 @@ class SqsTrigger:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, SqsTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, SqsTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, SqsTriggerRetry]):
     """
 
